@@ -23,7 +23,7 @@ def get_homepath() -> Path:
             return Path("NotImplemented")
         elif Path(SETTINGS_FILENAME) in Path().glob("*"):
             with open(Path() / SETTINGS_FILENAME) as f:
-                data = f.read()
-            return Path().cwd()
+                if "script-master" in f.readline():
+                    return Path().cwd()
 
         raise
